==> haskell-critbit-0.2.0.0-256-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-critbit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 critbit
version:              0.2.0.0
visibility:           public
id:                   critbit-0.2.0.0-CWV7Dvk3Xh33H1xBifgvOK
key:                  critbit-0.2.0.0-CWV7Dvk3Xh33H1xBifgvOK
license:              BSD-3-Clause
copyright:            2013-2014 Bryan O'\''Sullivan and others
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/critbit
synopsis:             Crit-bit maps and sets
description:
    This package implements crit-bit trees, a key-value container type
    for storing keys that can be treated as bitstrings (e.g.
    '\''ByteString'\'' and '\''Text'\'').

    Compared to the data structures from the containers and
    unordered-containers packages, you will find that sometimes the
    functions implemented in this package are faster, sometimes
    slower.

    In many cases, a '\''CritBit'\'' tree provides performance close to that
    of a '\''HashMap'\'', while providing ordered storage and traversal
    like a '\''Map'\''.

category:             Data
abi:                  9c56e144674db4bf8e971a4bef5cc4b7
exposed:              True
exposed-modules:      Data.CritBit.Map.Lazy Data.CritBit.Set
hidden-modules:
    Data.CritBit.Core Data.CritBit.Types.Internal Data.CritBit.Tree

import-dirs:          /usr/lib/ghc-9.2.8/site-local/critbit-0.2.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/critbit-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-critbit
hs-libraries:         HScritbit-0.2.0.0-CWV7Dvk3Xh33H1xBifgvOK
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 deepseq-1.4.6.1
    text-1.2.5.0 vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-critbit/html/critbit.haddock
haddock-html:         /usr/share/doc/haskell-critbit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-critbit-0.2.0.0-267-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-critbit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 critbit
version:              0.2.0.0
visibility:           public
id:                   critbit-0.2.0.0-4q03PCQI9b72namhqjyKnS
key:                  critbit-0.2.0.0-4q03PCQI9b72namhqjyKnS
license:              BSD-3-Clause
copyright:            2013-2014 Bryan O'\''Sullivan and others
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/critbit
synopsis:             Crit-bit maps and sets
description:
    This package implements crit-bit trees, a key-value container type
    for storing keys that can be treated as bitstrings (e.g.
    '\''ByteString'\'' and '\''Text'\'').

    Compared to the data structures from the containers and
    unordered-containers packages, you will find that sometimes the
    functions implemented in this package are faster, sometimes
    slower.

    In many cases, a '\''CritBit'\'' tree provides performance close to that
    of a '\''HashMap'\'', while providing ordered storage and traversal
    like a '\''Map'\''.

category:             Data
abi:                  bf9e214ec43c66d1b3d226c907a71a23
exposed:              True
exposed-modules:      Data.CritBit.Map.Lazy Data.CritBit.Set
hidden-modules:
    Data.CritBit.Core Data.CritBit.Types.Internal Data.CritBit.Tree

import-dirs:          /usr/lib/ghc-9.2.8/site-local/critbit-0.2.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/critbit-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-critbit
hs-libraries:         HScritbit-0.2.0.0-4q03PCQI9b72namhqjyKnS
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 deepseq-1.4.6.1
    text-1.2.5.0 vector-0.13.1.0-5Ks1FSmymfI2i781M8kBvn

haddock-interfaces:   /usr/share/doc/haskell-critbit/html/critbit.haddock
haddock-html:         /usr/share/doc/haskell-critbit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
